/**
 * Copyright 2010 ArcBees Inc.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */

package com.gwtplatform.annotation;

import java.lang.annotation.ElementType;
import java.lang.annotation.Inherited;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.lang.annotation.Target;

/**
 * Use with <code>@GenEvent</code> or <code>@GenDto</code> to specify the order
 * of the fields in the constructor parameter list.
 * <p/>
 * Fields with an @Order will be first, sorted numerically, and then fields
 * without an @Order will be afterwards in an undefined order.
 * <p/>
 * See {@link GenEvent} or {@link GenDto} for an example.
 * 
 * @author Brendan Doherty
 * @author Stephen Haberman (concept)
 */
@Target({ElementType.FIELD})
@Retention(RetentionPolicy.RUNTIME)
@Inherited
public @interface Order {
  int value();
}
